@@ -218,6 +218,11 @@ extern "C" {
 #include "compat/xstrto.h"
 #include "compat/xis.h"
 
+/*
+ * strtoll() is needed. Squid provides a portable definition.
+ */
+#include "compat/strtoll.h"
+
 #if !HAVE_MEMCPY
 #if HAVE_BCOPY
 #define memcpy(d,s,n) bcopy((s),(d),(n))
@@ -257,9 +262,4 @@ const char * squid_strnstr(const char *s, const char *find, size_t slen);
 #define PRINTF_FORMAT_ARG3
 #endif
 
-/* NULL is not always provided. */
-#ifndef NULL
-#define NULL ((void *)0)
-#endif
-
 #endif /* _SQUID_COMPAT_SHARED_H */
