@@ -1,5 +1,5 @@
 /*
- * $Id: MemBuf.h,v 1.10 2008/02/26 21:49:34 amosjeffries Exp $
+ * $Id$
  *
  *
  * SQUID Web Proxy Cache          http://www.squid-cache.org/
@@ -66,14 +66,14 @@ public:
 
     /// these space-related methods assume no growth and allow 0-termination
     char *space() { return buf + size; } // space to add data
-    char *space(mb_size_t required) { if (size + required > capacity) grow(size + required); return buf + size; } // space to add data
+    char *space(mb_size_t required) { if (size + required >= capacity) grow(size + required +1); return buf + size; } // space to add data
 
     mb_size_t spaceSize() const;
 
     /**
      * Whether the buffer contains any data space available.
-     \retval true	if data can be added to teh buffer
-     \retval false	if teh buffer is full
+     \retval true	if data can be added to the buffer
+     \retval false	if the buffer is full
      */
     bool hasSpace() const { return size+1 < capacity; }
 
@@ -85,6 +85,7 @@ public:
     void consume(mb_size_t sz);  // removes sz bytes, moving content left
     void append(const char *c, mb_size_t sz); // grows if needed and possible
     void appended(mb_size_t sz); // updates content size after external append
+    void truncate(mb_size_t sz);  // removes sz last bytes
 
     void terminate(); // zero-terminates the buffer w/o increasing contentSize
 
@@ -105,23 +106,12 @@ public:
     /** unfirtunate hack to test if the buffer has been Init()ialized */
     int isNull();
 
-#if STDC_HEADERS
-
     /**
      * calls snprintf, extends buffer if needed
      \note  we use Printf instead of printf so the compiler won't
      *      think we're calling the libc printf()
      */
     void Printf(const char *fmt,...) PRINTF_FORMAT_ARG2;
-#else
-
-    /**
-     * calls snprintf, extends buffer if needed
-     \note  we use Printf instead of printf so the compiler won't
-     *      think we're calling the libc printf()
-     */
-    void Printf();
-#endif
 
     /** vPrintf for other printf()'s to use */
     void vPrintf(const char *fmt, va_list ap);
@@ -179,7 +169,7 @@ public:
 #endif
 };
 
-#ifdef _USE_INLINE_
+#if _USE_INLINE_
 #include "MemBuf.cci"
 #endif
 
