@@ -35,8 +35,6 @@
 #ifndef SQUID_STRING_H
 #define SQUID_STRING_H
 
-#include "config.h"
-
 #if HAVE_OSTREAM
 #include <ostream>
 #endif
@@ -44,7 +42,7 @@
 /* squid string placeholder (for printf) */
 #ifndef SQUIDSTRINGPH
 #define SQUIDSTRINGPH "%.*s"
-#define SQUIDSTRINGPRINT(s) s.psize(),s.rawBuf()
+#define SQUIDSTRINGPRINT(s) (s).psize(),(s).rawBuf()
 #endif /* SQUIDSTRINGPH */
 
 
@@ -60,13 +58,11 @@ class StringRegistry
 public:
     static StringRegistry &Instance();
 
-    void add
-    (String const *);
+    void add(String const *);
 
     StringRegistry();
 
-    void remove
-    (String const *);
+    void remove(String const *);
 
 private:
     static OBJH Stat;
@@ -89,8 +85,8 @@ class String
 
 public:
     _SQUID_INLINE_ String();
-    String (char const *);
-    String (String const &);
+    String(char const *);
+    String(String const &);
     ~String();
 
     typedef size_t size_type; //storage size intentionally unspecified
@@ -136,7 +132,7 @@ public:
     void append(char const *buf, int len);
     void append(char const *buf);
     void append(char const);
-    void append (String const &);
+    void append(String const &);
     void absorb(String &old);
     const char * pos(char const *aString) const;
     const char * pos(char const ch) const;
@@ -146,19 +142,19 @@ public:
     size_type find(char const *aString) const;
     const char * rpos(char const ch) const;
     size_type rfind(char const ch) const;
-    _SQUID_INLINE_ int cmp (char const *) const;
-    _SQUID_INLINE_ int cmp (char const *, size_type count) const;
-    _SQUID_INLINE_ int cmp (String const &) const;
-    _SQUID_INLINE_ int caseCmp (char const *) const;
-    _SQUID_INLINE_ int caseCmp (char const *, size_type count) const;
-    _SQUID_INLINE_ int caseCmp (String const &) const;
+    _SQUID_INLINE_ int cmp(char const *) const;
+    _SQUID_INLINE_ int cmp(char const *, size_type count) const;
+    _SQUID_INLINE_ int cmp(String const &) const;
+    _SQUID_INLINE_ int caseCmp(char const *) const;
+    _SQUID_INLINE_ int caseCmp(char const *, size_type count) const;
+    _SQUID_INLINE_ int caseCmp(String const &) const;
 
     String substr(size_type from, size_type to) const;
 
     _SQUID_INLINE_ void cut(size_type newLength);
 
 #if DEBUGSTRINGS
-    void stat (StoreEntry *) const;
+    void stat(StoreEntry *) const;
 #endif
 
 
@@ -183,6 +179,8 @@ private:
 
 _SQUID_INLINE_ std::ostream & operator<<(std::ostream& os, String const &aString);
 
+_SQUID_INLINE_ bool operator<(const String &a, const String &b);
+
 #if _USE_INLINE_
 #include "String.cci"
 #endif
