@@ -32,7 +32,7 @@
  *
  */
 
-#include "config.h"
+#include "squid.h"
 #include "AccessLogEntry.h"
 #include "format/Quoting.h"
 #include "format/Token.h"
@@ -41,7 +41,7 @@
 #include "SquidTime.h"
 
 void
-Log::Format::SquidNative(AccessLogEntry * al, Logfile * logfile)
+Log::Format::SquidNative(const AccessLogEntry::Pointer &al, Logfile * logfile)
 {
     char hierHost[MAX_IPSTRLEN];
 
@@ -62,12 +62,9 @@ Log::Format::SquidNative(AccessLogEntry * al, Logfile * logfile)
         safe_free(user);
 
     char clientip[MAX_IPSTRLEN];
-    if (al->tcpClient != NULL)
-        al->tcpClient->remote.NtoA(clientip, sizeof(clientip));
-    else
-        al->cache.caddr.NtoA(clientip, sizeof(clientip));
+    al->getLogClientIp(clientip, MAX_IPSTRLEN);
 
-    logfilePrintf(logfile, "%9ld.%03d %6d %s %s%s/%03d %"PRId64" %s %s %s %s%s/%s %s%s",
+    logfilePrintf(logfile, "%9ld.%03d %6d %s %s%s/%03d %" PRId64 " %s %s %s %s%s/%s %s%s",
                   (long int) current_time.tv_sec,
                   (int) current_time.tv_usec / 1000,
                   al->cache.msec,
