@@ -1,6 +1,6 @@
 
 /*
- * $Id: store_repl_heap.cc,v 1.25 2007/04/30 16:56:19 wessels Exp $
+ * $Id$
  *
  * DEBUG: section 81    Store HEAP Removal Policies
  * AUTHOR: Henrik Nordstrom
@@ -41,7 +41,7 @@
  *
  */
 
-#include "squid.h"
+#include "squid-old.h"
 #include "heap.h"
 #include "store_heap_replacement.h"
 #include "Store.h"
@@ -336,7 +336,10 @@ createRemovalPolicy_heap(wordlist * args)
     }
 
     /* No additional arguments expected */
-    assert(!args);
+    while (args) {
+        debugs(81, DBG_IMPORTANT, "WARNING: discarding unknown removal policy '" << args->key << "'");
+        args = args->next;
+    }
 
     heap_data->theHeap = new_heap(1000, heap_data->keyfunc);
 
